<template>
  <div class="app-container">
    <el-page-header @back="goBack" content="详情页面">
    </el-page-header>

    <el-container>
      <el-main>
        <h2>考核规则</h2>
        <el-table v-loading="loading" :data="checkRuleList" @selection-change="handleSelectionChange">
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column label="规则名称" align="center" prop="checkRuleName" />
          <el-table-column label="规则权重" align="center" prop="weight" />
          <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
            <template slot-scope="scope">
              <el-button
                size="mini"
                type="text"
                icon="el-icon-edit"
                @click="handleRuleUpdate(scope.row)"
              >修改</el-button>
            </template>
          </el-table-column>
        </el-table>

        <pagination
          v-show="total>0"
          :total="total"
          :page.sync="queryParams.pageNum"
          :limit.sync="queryParams.pageSize"
          @pagination="getRuleList"
        />
      </el-main>
    </el-container>

    <el-container>
      <el-main>
        <h2>考核成绩</h2>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button
              type="warning"
              plain
              icon="el-icon-download"
              size="mini"
              @click="handleExport"
            >导出</el-button>
          </el-col>
          <right-toolbar :showSearch.sync="showSearch" @queryTable="getRuleList"></right-toolbar>
        </el-row>

        <el-table  v-loading="loading" :data="dataMap" @selection-change="handleSelectionChange">
          <el-table-column label="考核日期" align="center" prop="create_time" width="120px" fixed>
            <template slot-scope="scope">
              <span>{{ scope.row.create_time.split('T')[0] }}</span>
            </template>
          </el-table-column>
          <el-table-column label="考核对象" align="center" prop="dept_id" width="120px" fixed>
            <template slot-scope="scope">
              <span>{{ translateDeptId(scope.row.dept_id) }}</span>
            </template>
          </el-table-column>
          <template v-for="item in tableData">
            <el-table-column
              :key="item.ruleName"
              :label="item.ruleName"
              align="center"
              width = "120px"
            >
              <template slot-scope="scope">
                <span>{{ scope.row[item.ruleIndex] }}</span>
              </template>
            </el-table-column>
          </template>
          <el-table-column label="操作" align="center" class-name="small-padding fixed-width"  fixed="right">
            <template slot-scope="scope">
              <el-button
                size="mini"
                type="text"
                icon="el-icon-edit"
                @click="handleIndexUpdate(scope.row,scope.index)"
              >修改</el-button>
            </template>
          </el-table-column>
        </el-table>
      </el-main>
    </el-container>

    <!-- 修改考核权重对话框 -->
    <el-dialog :title="title" :visible.sync="ruleOpen" width="600px" append-to-body>
      <el-form ref="form" :model="ruleForm" :rules="rules" label-width="80px">
        <el-form-item label="规则名称" prop="checkRuleName">
          <el-input v-model="ruleForm.checkRuleName" placeholder="请输入规则名称" disabled/>
        </el-form-item>
        <el-form-item label="规则权重" prop="weight">
          <el-input-number v-model="ruleForm.weight" :precision="1" placeholder="请输入规则权重" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!-- 修改考核指标对话框 -->
    <el-dialog :title="title" :visible.sync="indexOpen" width="600px" append-to-body>
      <el-form ref="form" :model="indexForm" :rules="rules" label-width="150px">
        <el-form-item label="考核日期" prop="create_time">
          <el-input v-model="ruleForm.create_time" placeholder="请输入规则名称" disabled>

          </el-input>
        </el-form-item>
<!--        <el-form-item label="考核对象" prop="checkRuleName">-->
<!--          <el-input v-model="ruleForm.checkRuleName" placeholder="请输入规则名称" disabled/>-->
<!--        </el-form-item>-->
        <div v-for="item in tableData" :key="item.ruleIndex">
          <el-form-item :label="item.ruleName" :prop="item.ruleIndex">
            <el-input-number v-model="indexForm[item.ruleIndex]" :precision="4" placeholder="请输入指标"></el-input-number>
          </el-form-item>
        </div>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listCheckResult, getCheckResult, delCheckResult, addCheckResult, updateCheckResult,manualScore, publishCheckResult } from "@/api/platform/check-result";
import { listScore, getScoreIndex, delScore, addScore, updateScore } from "@/api/platform/check-score";
import { areaSelect } from '@/api/system/dept'

export default {
  name: "CheckResult",
  dicts: ['platform_audit_state'],
  data() {
    return {
      id: null,
      examineTag: null,
      deptId: null,
      areaList:[],
      tableData: [],
      dataMap: [],
      manualScoreOpen: false,
      manualScoreForm: {},
      manualScoreTitle: '',
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 考核结果表格数据
      checkRuleList: [],
      scoreTotal: 3,
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      ruleOpen: false,
      indexOpen: false,
      // 逻辑删除时间范围
      daterangeCheckTime: [],
      // 表单参数
      indexForm: {},
      ruleForm: {},
      //请求参数
      queryParams: {
        id: null,
      },
      // 表单校验
      rules: {}
    };
  },
  created() {
    //考核成绩详情跳转参数接收
    if(this.$route.query.id){
      this.id = this.$route.query.id
    }
    // 考核积分列表
    this.getList();
    this.areaSelect();
  },
  methods: {
    /** 查询考核计分列表 */
    getList() {
      this.loading = true;
      getScoreIndex(this.id).then(response => {
        this.checkRuleList = response.data.checkRuleList;
        this.dataMap = response.data.scoreMap.dataMap;
        this.tableData = response.data.scoreMap.tableData
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.ruleOpen = false;
      this.indexOpen = false;
      this.reset("ruleForm");
      this.reset("indexForm");
    },
    // 表单重置
    reset(formName) {
      this.ruleForm = {
        checkRuleName: null,
        weight: null,
      };
      this.indexForm = {
      };
      this.resetForm(formName);
    },
    translateDeptId(deptId) {
      const department = this.areaList.find(dept => dept.id == deptId);
      return department ? department.value : '未知';
    },
    // 区域下拉数据
    areaSelect() {
      areaSelect().then(res => {
        this.areaList = res.data;
      })
    },
    cancelManualScore() {
      this.manualScoreForm = {};
      this.manualScoreTitle = "";
      this.manualScoreOpen = false;
    },
    submitManualScore() {
      if (! this.manualScoreForm.manualScore) {
        this.$modal.msgWarning("请填写分数");
        return
      }
      manualScore(this.manualScoreForm).then(res => {
        this.$modal.msgSuccess("操作成功");
        this.cancelManualScore();
        this.getList();
      })
    },
    handleSetManualScore(row) {
      this.manualScoreForm.id = row.id;
      this.manualScoreForm.manualScore = parseInt(row.manualScore);
      this.manualScoreTitle = row.checkUnitName + '人工打分'
      this.manualScoreOpen = true;
    },

    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.daterangeCheckTime = [];
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加考核结果";
    },
    /** 修改指标按钮操作 */
    handleIndexUpdate(row) {
      this.reset("indexForm");
      this.indexForm = row;
      this.indexOpen = true;
      this.title = "修改考核指标";
    },
    /** 修改按钮操作 */
    handleRuleUpdate(row) {
      this.reset("ruleForm");
      this.ruleForm = row;
      this.ruleOpen = true;
      this.title = "修改考核规则";
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateCheckResult(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addCheckResult(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除考核结果编号为"' + ids + '"的数据项？').then(function() {
        return delCheckResult(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/checkResult/export', {
        ...this.queryParams
      }, `checkResult_${new Date().getTime()}.xlsx`)
    },
    handleSelect(key, keyPath) {
      console.log(key, keyPath);
    },
  }
};
</script>
<style scoped>

.line {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
}

.line-right {
  width: 50px;
}
.input{
  width: 200px;
}

.input-w {
  margin-left: 5px;
  width: 70px;
}
.row-warp {
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  border: solid 1px gray;
  /*padding: 3px;*/
}
.row {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  border-bottom: solid 1px gray;
  padding: 3px;
}
.row:last-of-type {
  border-bottom: none;
}
.row-left {
  flex: 2;
  border-right: solid 1px gray;
}
.row-right {
  flex: 4;
  display: flex;
  flex-direction: row;
  justify-content: center;
}
.header-container {
  display: flex;
  align-items: center; /* 垂直居中 */
}

.header-container h2 {
  margin-right: 10px; /* 根据需要调整标题和菜单之间的间距 */
}

</style>
